<?php

namespace Concrete\Package\AbStrToImg\Block\AbStrToImg;

use Concrete\Core\Block\BlockController;

/**
 * ab_str_to_img package for Concrete5
 * concrete5.org marketplace license
 * Copyright Copyright 2017-2018, Alex Borisov
 *
 * @author Alex Borisov <linuxoidoz@gmail.com>
 * @package Concrete\Package\ab_str_to_img
 */
 
class Controller extends BlockController
{
    
    protected $btWrapperClass = 'ccm-ui';
    protected $btInterfaceWidth = "400";
    protected $btInterfaceHeight = "200";
    protected $btTable = 'btAbStrToImg';
    protected $btDefaultSet = 'multimedia';
    
    public function getBlockTypeDescription() 
    {
        return t("Add String to Image Converter block");
    }

    public function getBlockTypeName() 
    {
        return t("String to Image Converter");
    }

    public function view() 
    {
        $this->set('img', $this->img);
    }

    public function save($args) 
    {
        $args['img_string'] = isset($args['img_string']) ? trim($args['img_string']) : '';
        $args['img'] = isset($args['img_string']) ? base64_encode($this->make_image($args['img_string'])) : '';
        parent::save($args);
    }

    public function validate($args)
    {
        $e = $this->app->make('helper/validation/error');
        $img_string = trim($args['img_string']);
        
        if ((mb_strlen($img_string, 'UTF-8') < 1) || (mb_strlen($img_string, 'UTF-8') > 100)) {
            $e->add(t('Image text cannot be empty or > 100 symbols!'));
        }

        return $e;
    }

    public function make_image($img_str = '')
    {
        $font_size = 4;
        $width = imagefontwidth($font_size) * strlen($img_str);
        $height = imagefontheight($font_size);

        $img = @imagecreatetruecolor($width, $height);
        imagesavealpha($img, true);
        $trans_colour = imagecolorallocatealpha($img, 0, 0, 0, 127);
        imagefill($img, 0, 0, $trans_colour);
        $textcolor = imagecolorallocate($img, 0, 0, 0);
        imagestring($img, $font_size, 0, 0, $img_str, $textcolor);
        
        ob_start();
        imagepng($img);
        $imgData = ob_get_clean();
        imagedestroy($img);
            
        return $imgData;
    }
     
}
